@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: DeviceConfigView.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: DeviceConfigView.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object presents the devices in the configuration window
  *
@@ -40,10 +40,11 @@ public:
     virtual ~DeviceConfigView();
 
 protected:
-    void mousePressEvent ( QMouseEvent * e );
+    virtual void mousePressEvent ( QMouseEvent * e );
 
 signals:
-    void deviceClick(QMouseEvent *);
+	void deviceClick(QMouseEvent *);
+	void deviceDoubleClick(QMouseEvent *);
 };
 
 #endif /* DEVICECONFIGVIEW_H_ */
