@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: StatusUpdateCollector.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: StatusUpdateCollector.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This is the base class for all objects receiving status updates
  *
@@ -27,7 +27,7 @@
 #ifndef STATUSUPDATECOLLECTOR_H_
 #define STATUSUPDATECOLLECTOR_H_
 
-#include <string>
+#include <QString>
 
 class StatusUpdateCollector
 {
@@ -35,7 +35,7 @@ public:
   StatusUpdateCollector();
   virtual ~StatusUpdateCollector();
 
-  virtual void notify(const std::string& ) = 0;
+  virtual bool notify(const QByteArray& ) = 0;
 };
 
 #endif /* STATUSUPDATECOLLECTOR_H_ */
