@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: CommandLine.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: CommandLine.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object manages the command line widget
  *
@@ -39,6 +39,9 @@ public:
   CommandLine(QWidget * parent=NULL );
   virtual ~CommandLine();
   void setFont();
+  bool empty();
+  void save();
+  void restore();
 
   QSize sizeHint();
 
@@ -49,7 +52,7 @@ private slots:
     void enterPressed(const QString & text);
 
 private:
-  std::vector<std::string> history;
+  QVector<QString> mHistory;
   int mHistoryPtr;
 
   void setLine();
