@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: HerculesExecutor.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: HerculesExecutor.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object runs hercules as a child process
  *
@@ -26,19 +26,32 @@
 
 #ifndef HERCULESEXECUTOR_H_
 #define HERCULESEXECUTOR_H_
-#include "MainWindow.h"
+#include <QMainWindow>
+#include <QProcess>
 #include <string>
 
 class HerculesExecutor
 {
 public:
-  HerculesExecutor(QMainWindow& mainWindow);
+  HerculesExecutor(QMainWindow& mainWindow, int pid=0);
   virtual ~HerculesExecutor();
 
-  int run(std::string& configName, std::string& herculesPath);
+  int run(std::string configName, std::string herculesPath);
+  void issueCommand(const char * command);
+  void issueFormattedCommand(const char *format, const char * arg1);
+  void issueFormattedCommand(const char *format, const int arg1);
+  void issueFormattedCommand(const char *format, const char * arg1, const char *arg2);
+  QByteArray getLine();
+  bool getLine(char * buff, int max);
+  QByteArray getStatusLine();
+  bool getStatusLine(char * buff, int max);
+  QProcess * getQProcess(){ return mProcess; };
+  int state() {return mProcess->state();};
 
 private:
   QMainWindow & mMainWindow;
+  QProcess    *mProcess;
+  int	  	  mPid;
 };
 
 #endif /* HERCULESEXECUTOR_H_ */
