@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: LogRunner.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: LogRunner.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object collects data from the hercules log into the queue
  *
@@ -28,23 +28,34 @@
 #define LOGRUNNER_H_
 
 #include "Runner.h"
+#include "HerculesStudio.h"
 #include "SynchronizedQueue.h"
+#include "HerculesExecutor.h"
 
 #include <QThread>
 #include <QWidget>
 
+class QProcess;
 class LogRunner :  public Runner
 {
   Q_OBJECT
 public:
-  LogRunner(SynchronizedQueue& logQueue);
+  LogRunner(SynchronizedQueue& logQueue, HerculesExecutor * herculesExecutor, int maxQueueSize);
   virtual ~LogRunner();
 
-  virtual void run();
+  void run();
 
 private:
   std::string mLogFifo;
+  HerculesExecutor *mHerculesExecutor;
+  QProcess *mProcess;
   bool mRunning;
+  int mMaxQueueSize;
+
+public slots:
+#ifdef hFramework
+ void readStandardOutput();
+#endif
 };
 
 #endif /* LOGRUNNER_H_ */
