@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Mips.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: Mips.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object presents the current mips reading as received from hercules
  *
@@ -36,7 +36,7 @@ public:
     virtual ~Mips();
 
     virtual void display(double value) = 0;
-    virtual void setVisible(bool) = 0;
+	virtual void setActive(bool) = 0;
     virtual void move(int, int) = 0;
     virtual void setToolTip(const QString &) = 0;
     virtual void deleteLater(void) = 0;
