@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: June 15, 2010
  *
- *  Copyright (c) 2009-2010 Jacob Dekel
- *  $Id: Mips.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: MipsLed.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object presents the current mips reading in LCD format
  *
@@ -39,7 +39,7 @@ public:
     virtual ~MipsLed();
 
     virtual void display(double);
-    virtual void setVisible(bool visible);
+	virtual void setActive(bool active);
     virtual void move(int, int);
     virtual void setToolTip(const QString & tip);
     virtual void deleteLater(void);
@@ -47,6 +47,7 @@ public:
 
 private:
     QLCDNumber *mMips;
+	QPalette mMipsPalette;
 };
 
 #endif /* MIPSLCD_H_ */
