@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Regs64.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: Regs64.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object implements the 64-bit registers view
  *
@@ -37,7 +37,7 @@ public:
 
 	void setFont();
 	void setActive(bool active);
-	void notify(const std::string& statusLine);
+	bool notify(const QByteArray& statusLine);
 	static std::string gCommand;
 	static std::string fCommand;
 	static std::string cCommand;
