@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: StatusRunner.cpp 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: StatusRunner.cpp 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,12 +23,13 @@
  */
 
 #include "StatusRunner.h"
+#include "HerculesStudio.h"
 #include "NamedPipe.h"
 
 #include <fcntl.h>
 
-StatusRunner::StatusRunner(SynchronizedQueue& statusQueue)
-: Runner(statusQueue)
+StatusRunner::StatusRunner(SynchronizedQueue& statusQueue, HerculesExecutor * herculesExecutor)
+: Runner(statusQueue), mHerculesExecutor(herculesExecutor)
 {
 
 }
@@ -39,19 +40,44 @@ StatusRunner::~StatusRunner()
 
 void StatusRunner::run()
 {
-	FILE * statusFile = NamedPipe::getInstance().getHerculesStatus();
-	char buff[512];
+#ifdef hFramework
+	mProcess = mHerculesExecutor->getQProcess();
+	connect(mHerculesExecutor->getQProcess(),
+			SIGNAL(readyReadStandardError()),
+			this,
+			SLOT(readStandardError()));
+	return;
+#else
+	QFile& statusFile = NamedPipe::getInstance().getHerculesStatus();
+	QByteArray buff;
+	buff.resize(512);
 	mRunning = true;
 	while(mRunning)
 	{
-		if (fgets(buff,512,statusFile) == NULL)
+		int size;
+		if ((size = statusFile.readLine(buff.data(),512)) <= 0)
 		{
 			emit newData();
 			break;
 		}
-	if (buff[0]) buff[strlen(buff)-1] = '\0'; // remove CR
-	mQueue.push_back(buff);
-	emit newData();
+		buff[size-1] = '\0';
+		mQueue.push_back(buff);
+		emit newData();
+	}
+#endif
+}
+
+
+void StatusRunner::readStandardError()
+{
+	mProcess->setReadChannel(QProcess::StandardError);
+	while (true)
+	{
+		QByteArray output = mProcess->readLine();
+		if (output.length() == 0) break;
+		output[output.length()-1]='\0';
+		mQueue.push_back(output.data());
+		emit newData();
 	}
 }
 
