@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: StatusRunner.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: StatusRunner.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object collects status data from hercules
  *
@@ -27,18 +27,26 @@
 #ifndef STATUSRUNNER_H_
 #define STATUSRUNNER_H_
 #include "Runner.h"
+#include "SynchronizedQueue.h"
+#include "HerculesExecutor.h"
 
+#include <QProcess>
 
 class StatusRunner : public Runner
 {
   Q_OBJECT
 public:
-  StatusRunner(SynchronizedQueue& statusQueue);
+  StatusRunner(SynchronizedQueue& statusQueue, HerculesExecutor * herculesExecutor);
   virtual ~StatusRunner();
 
   virtual void run();
 
 private:
+  HerculesExecutor * mHerculesExecutor;
+  QProcess *mProcess;
+
+public slots:
+  void readStandardError();
 };
 
 #endif /* STATUSRUNNER_H_ */
