@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: SynchronizedQueue.cpp 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: SynchronizedQueue.cpp 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,12 +40,12 @@ bool SynchronizedQueue::empty() const
     return mQueue.empty();
 }
 
-std::string& SynchronizedQueue::front()
+QByteArray& SynchronizedQueue::front()
 {
     return mQueue.front();
 }
 
-void SynchronizedQueue::push_back(const std::string& str)
+void SynchronizedQueue::push_back(const QByteArray& str)
 {
     QMutexLocker lock(&mMutex);
     mQueue.push_back(str);
@@ -56,3 +56,13 @@ void SynchronizedQueue::pop_front()
     QMutexLocker lock(&mMutex);
     mQueue.pop_front();
 }
+
+int SynchronizedQueue::size()
+{
+	return mQueue.size();
+}
+
+void SynchronizedQueue::clear()
+{
+	mQueue.clear();
+}
