@@ -4,10 +4,10 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: SynchronizedQueue.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: SynchronizedQueue.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
- *	This object implementa queue to which is access is serialized on write
+ *	This object implements a queue to which access is serialized
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,21 +27,23 @@
 #ifndef SYNCHRONIZEDQUEUE_H_
 #define SYNCHRONIZEDQUEUE_H_
 #include <QMutex>
-#include <string>
-#include <list>
+#include <QByteArray>
+#include <deque>
 
-typedef std::list<std::string> HercQueue;
+typedef std::deque<QByteArray> HercQueue;
 
 class SynchronizedQueue
 {
 public:
-  SynchronizedQueue();
-  virtual ~SynchronizedQueue();
+	SynchronizedQueue();
+	virtual ~SynchronizedQueue();
 
-  bool            empty ( ) const;
-  std::string&    front ( ) ;
-  void            pop_front ( );
-  void            push_back(const std::string& charBuff);
+	bool            empty ( ) const;
+	QByteArray&     front ( ) ;
+	void            pop_front ( );
+	void            push_back(const QByteArray& charBuff);
+	int				size( );
+	void            clear( );
 
 private:
     HercQueue   mQueue;
