@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Watchdog.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: Watchdog.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object is the watchdog for the hercules process
  *
@@ -28,12 +28,14 @@
 #define WATCHDOG_H_
 
 #include <QThread>
+#include <QProcess>
 
 class Watchdog : public QThread
 {
 	Q_OBJECT
 public:
 	Watchdog(int herculesPid, bool child);
+  Watchdog(QProcess * herculesProcess);
 	virtual ~Watchdog();
 
 	virtual void run();
@@ -44,9 +46,7 @@ signals:
 private:
 	int mHerculesPid;
 	bool mChild;
-
-    bool processIsRunning(int pid); // TODO: merge with NamedPipe (same function!)
-    bool fileExists(const std::string & pid); // TODO: merge with NamedPipe (same function!)
+  QProcess * mProcess;
 };
 
 #endif /* WATCHDOG_H_ */
