@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: DasdLoad.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: DasdLoad.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	Dasdload utility object
  *
@@ -30,6 +30,7 @@
 #include <QtGui/QDialog>
 #include "ui_DasdLoad.h"
 
+class UtilityExecutor;
 class DasdLoad : public QDialog
 {
     Q_OBJECT
@@ -40,20 +41,16 @@ public:
 
 private:
     Ui::DasdLoadClass ui;
-    int               mPid;
     bool              mEnded;
+    UtilityExecutor * mExecutor;
 
 private slots:
     void exitClicked();
     void runClicked();
     void runnerMaximumChanged(int maximum);
     void runnerValueChanged(int value);
-    void runnerError(const QString& errorLine);
     void browseCtlClicked();
     void browseOutClicked();
-
-signals:
-    void output(QString line);
 };
 
 #endif // DASDLOAD_H
