@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Dasdcat.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: Dasdcat.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	Dasdcat utility object
  *
@@ -27,10 +27,14 @@
 #ifndef DASDCAT_H
 #define DASDCAT_H
 
+#include "GenericUtility.h"
+
 #include <QtGui/QDialog>
 #include "ui_Dasdcat.h"
 
-class Dasdcat : public QDialog
+class UtilityExecutor;
+
+class Dasdcat : public GenericUtility
 {
     Q_OBJECT
 
@@ -41,7 +45,7 @@ public:
 private:
     Ui::DasdcatClass ui;
 
-    int     mPid;
+    virtual void finishedSlot();
 
 private slots:
     void exitClicked();
@@ -49,12 +53,6 @@ private slots:
     void browseFileClicked();
     void browseSfClicked();
     void specificToggeled(bool);
-    void runnerMaximumChanged(int maximum);
-    void runnerValueChanged(int value);
-    void runnerError(const QString& errorLine);
-
-signals:
-    void output(QString line);
 };
 
 #endif // DASDCAT_H
