@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 7, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id: Dasdconv.h 34 2009-11-07 06:15:58Z jacob $
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: Dasdconv.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	Dasdconv utility object
  *
@@ -27,10 +27,14 @@
 #ifndef DASDCONV_H
 #define DASDCONV_H
 
+#include "GenericUtility.h"
+
 #include <QtGui/QDialog>
 #include "ui_Dasdconv.h"
 
-class Dasdconv : public QDialog
+class UtilityExecutor;
+
+class Dasdconv : public GenericUtility
 {
     Q_OBJECT
 
@@ -38,9 +42,6 @@ public:
     Dasdconv(QWidget *parent = 0);
     virtual ~Dasdconv();
 
-signals:
-    void output(QString line);
-
 private slots:
     void runClicked();
     void exitClicked();
@@ -48,12 +49,11 @@ private slots:
     void browseOutClicked();
     void runnerMaximumChanged(int maximum);
     void runnerValueChanged(int value);
-    void runnerError(const QString& errorLine);
 
 private:
     Ui::DasdconvClass ui;
 
-    int     mPid;
+	virtual void finishedSlot();
 };
 
 #endif // DASDCONV_H
