@@ -4,8 +4,8 @@
  *  Author:     Jacob Dekel
  *  Created on: Aug 24, 2009
  *
- *  Copyright (c) 2009 Jacob Dekel
- *  $Id:
+ *  Copyright (c) 2009-2013 Jacob Dekel
+ *  $Id: SystemUtils.h 161 2012-12-13 06:47:20Z dekeljacob $
  *
  *	This object provides system-level utilities to other utilities
  *
@@ -27,6 +27,7 @@
 #ifndef SYSTEMUTILS_H_
 #define SYSTEMUTILS_H_
 
+#include <QString>
 #include <string>
 
 class SystemUtils
@@ -37,6 +38,7 @@ public:
 
 	static bool processIsRunning(int pid);
 	static bool fileExists(const std::string& filename);
+	static bool fileExists(const QString& filename);
 };
 
 #endif /* SYSTEMUTILS_H_ */
